==> libreoffice-still-sdk-5.0.6-1-armv7h.pkg.tar.xz: usr/share/doc/libreoffice/sdk/docs/idl/ref/search/files_a.js <==
var searchData=
[
  ['kcharactertype_2eidl',['KCharacterType.idl',['../KCharacterType_8idl.html',1,'']]],
  ['keeptogether_2eidl',['KeepTogether.idl',['../KeepTogether_8idl.html',1,'']]],
  ['key_2eidl',['Key.idl',['../awt_2Key_8idl.html',1,'']]],
  ['key_2eidl',['Key.idl',['../sdbcx_2Key_8idl.html',1,'']]],
  ['keycolumn_2eidl',['KeyColumn.idl',['../KeyColumn_8idl.html',1,'']]],
  ['keycolumndescriptor_2eidl',['KeyColumnDescriptor.idl',['../KeyColumnDescriptor_8idl.html',1,'']]],
  ['keydescriptor_2eidl',['KeyDescriptor.idl',['../KeyDescriptor_8idl.html',1,'']]],
  ['keyevent_2eidl',['KeyEvent.idl',['../KeyEvent_8idl.html',1,'']]],
  ['keyexception_2eidl',['KeyException.idl',['../KeyException_8idl.html',1,'']]],
  ['keyfunction_2eidl',['KeyFunction.idl',['../KeyFunction_8idl.html',1,'']]],
  ['keygroup_2eidl',['KeyGroup.idl',['../KeyGroup_8idl.html',1,'']]],
  ['keymodifier_2eidl',['KeyModifier.idl',['../KeyModifier_8idl.html',1,'']]],
  ['keyrule_2eidl',['KeyRule.idl',['../KeyRule_8idl.html',1,'']]],
  ['keystroke_2eidl',['KeyStroke.idl',['../KeyStroke_8idl.html',1,'']]],
  ['keytype_2eidl',['KeyType.idl',['../KeyType_8idl.html',1,'']]],
  ['keyusage_2eidl',['KeyUsage.idl',['../KeyUsage_8idl.html',1,'']]],
  ['keywords_2eidl',['Keywords.idl',['../Keywords_8idl.html',1,'']]],
  ['knumberformattype_2eidl',['KNumberFormatType.idl',['../KNumberFormatType_8idl.html',1,'']]],
  ['knumberformatusage_2eidl',['KNumberFormatUsage.idl',['../KNumberFormatUsage_8idl.html',1,'']]],
  ['kparsetokens_2eidl',['KParseTokens.idl',['../KParseTokens_8idl.html',1,'']]],
  ['kparsetype_2eidl',['KParseType.idl',['../KParseType_8idl.html',1,'']]]
];

==> libreoffice-still-sdk-6.0.6-3-armv7h.pkg.tar.xz: usr/share/doc/libreoffice/sdk/docs/idl/ref/search/files_a.js <==
var searchData=
[
  ['kcharactertype_2eidl',['KCharacterType.idl',['../KCharacterType_8idl.html',1,'']]],
  ['keeptogether_2eidl',['KeepTogether.idl',['../KeepTogether_8idl.html',1,'']]],
  ['key_2eidl',['Key.idl',['../awt_2Key_8idl.html',1,'(Global Namespace)'],['../sdbcx_2Key_8idl.html',1,'(Global Namespace)']]],
  ['keycolumn_2eidl',['KeyColumn.idl',['../KeyColumn_8idl.html',1,'']]],
  ['keycolumndescriptor_2eidl',['KeyColumnDescriptor.idl',['../KeyColumnDescriptor_8idl.html',1,'']]],
  ['keydescriptor_2eidl',['KeyDescriptor.idl',['../KeyDescriptor_8idl.html',1,'']]],
  ['keyevent_2eidl',['KeyEvent.idl',['../KeyEvent_8idl.html',1,'']]],
  ['keyexception_2eidl',['KeyException.idl',['../KeyException_8idl.html',1,'']]],
  ['keyfunction_2eidl',['KeyFunction.idl',['../KeyFunction_8idl.html',1,'']]],
  ['keygroup_2eidl',['KeyGroup.idl',['../KeyGroup_8idl.html',1,'']]],
  ['keymodifier_2eidl',['KeyModifier.idl',['../KeyModifier_8idl.html',1,'']]],
  ['keyrule_2eidl',['KeyRule.idl',['../KeyRule_8idl.html',1,'']]],
  ['keystroke_2eidl',['KeyStroke.idl',['../KeyStroke_8idl.html',1,'']]],
  ['keytype_2eidl',['KeyType.idl',['../KeyType_8idl.html',1,'']]],
  ['keyusage_2eidl',['KeyUsage.idl',['../KeyUsage_8idl.html',1,'']]],
  ['keywords_2eidl',['Keywords.idl',['../Keywords_8idl.html',1,'']]],
  ['knumberformattype_2eidl',['KNumberFormatType.idl',['../KNumberFormatType_8idl.html',1,'']]],
  ['knumberformatusage_2eidl',['KNumberFormatUsage.idl',['../KNumberFormatUsage_8idl.html',1,'']]],
  ['kparsetokens_2eidl',['KParseTokens.idl',['../KParseTokens_8idl.html',1,'']]],
  ['kparsetype_2eidl',['KParseType.idl',['../KParseType_8idl.html',1,'']]]
];
